//
//  MainMenu.swift
//  ArkitDoushiQi
//
//  Created by Johan LACHENAL on 16/05/2024.
//
import SwiftUI

struct AnimatedCherryBlossomView: View {
    @State private var moveTrees = false
    @Environment(\.colorScheme) var colorScheme

    var body: some View {
        ZStack {
            // Arbre gauche
            Image(colorScheme == .dark ? "cherry_tree_dark" : "cherry_tree_light")
                .resizable()
                .scaledToFit()
                .frame(width: 200, height: 400)
                .offset(x: moveTrees ? -20 : -40, y: moveTrees ? 10 : 30)
                .animation(Animation.easeInOut(duration: 3).repeatForever(autoreverses: true))
            
            // Arbre droit
            Image(colorScheme == .dark ? "cherry_tree_dark" : "cherry_tree_light")
                .resizable()
                .scaledToFit()
                .frame(width: 200, height: 400)
                .offset(x: moveTrees ? 20 : 40, y: moveTrees ? 10 : 30)
                .animation(Animation.easeInOut(duration: 3).repeatForever(autoreverses: true))
        }
        .onAppear {
            moveTrees.toggle()
        }
    }
}

struct MainMenu: View {
    @EnvironmentObject var languageSettings: LanguageSettings
    let playButtonText: String
    let registeredGamesButtonText: String
    @State private var action: Int? = 0
    @AppStorage("isDarkMode") private var isDarkMode = false
    @State private var reloadView = false
    @State private var showLanguagePicker = false
    @ScaledMetric(relativeTo: .body) var scaledPadding: CGFloat = 10
    @Environment(\.colorScheme) var colorScheme

    var body: some View {
        NavigationView {
            ZStack {
                // Utiliser la vue animée en arrière-plan
                AnimatedCherryBlossomView()
                    .edgesIgnoringSafeArea(.all)

                VStack {
                    // Ajouter le titre du jeu
                    Text("DOUSHIQI")
                        .font(.custom("Nuku Nuku", size: 48, relativeTo: .largeTitle)) // Utilisez le nom PostScript correct
                        .padding()
                        .foregroundColor(colorScheme == .dark ? .white : .black)
                        .offset(x: 0, y: 15)
                    
                    Text("GAME")
                        .font(.custom("Nuku Nuku", size: 48, relativeTo: .largeTitle)) // Utilisez le nom PostScript correct
                        .foregroundColor(colorScheme == .dark ? .white : .black)
                    
                    Spacer()

                    // Bouton "Jouer" au centre et plus grand, sans bandeau bleu
                    NavigationLink(destination: GameParametersMenuView()) {
                        Text(playButtonText)
                            .font(.custom("Nuku Nuku", size: 32, relativeTo: .title))
                            .bold()
                            .frame(maxWidth: .infinity)
                            .padding()
                            .background(Color.white.opacity(0.2))
                            .foregroundColor(colorScheme == .dark ? .white : .black)
                            .cornerRadius(10)
                            .overlay(
                                RoundedRectangle(cornerRadius: 10)
                                    .stroke(colorScheme == .dark ? Color.white : Color.black, lineWidth: 2)
                            )
                            .shadow(radius: 10)
                            .padding(scaledPadding)
                    }
                    .padding(.horizontal, 50)

                    Spacer().frame(height: 40)

                    // Bouton "Parties enregistrées" plus discret
                    NavigationLink(destination: PartyListView()) {
                        Text(registeredGamesButtonText)
                            .font(.custom("Nuku Nuku", size: 18, relativeTo: .body))
                            .padding()
                            .background(Color.gray.opacity(0.7))
                            .foregroundColor(colorScheme == .dark ? .white : .black)
                            .cornerRadius(10)
                            .shadow(radius: 5)
                            .padding(scaledPadding)
                    }
                    .padding(.horizontal, 50)

                    Spacer().frame(height: 20)
                    
                    // Ajouter les icônes pour les paramètres en bas du bouton "Registered Games"
                    HStack {
                        Button(action: {
                            isDarkMode.toggle()
                        }) {
                            Image(systemName: isDarkMode ? "sun.max.fill" : "moon.fill")
                                .foregroundColor(colorScheme == .dark ? .white : .black)
                                .padding()
                                .scaleEffect(1.2)
                        }

                        Button(action: {
                            // Afficher le sélecteur de langue
                            showLanguagePicker.toggle()
                        }) {
                            Image(systemName: "globe")
                                .foregroundColor(colorScheme == .dark ? .white : .black)
                                .padding()
                                .scaleEffect(1.2)
                        }
                        .sheet(isPresented: $showLanguagePicker) {
                            LanguagePickerView(showLanguagePicker: $showLanguagePicker)
                                .environmentObject(languageSettings)
                        }
                    }
                    .padding(scaledPadding)
                    
                    Spacer()
                }
                .padding(EdgeInsets(top: 10, leading: 32, bottom: 10, trailing: 32))
            }
            .environmentObject(languageSettings)
            .onReceive(NotificationCenter.default.publisher(for: NSNotification.Name("LanguageChanged"))) { _ in
                self.reloadView.toggle() // Changez la valeur pour forcer le rechargement
            }
        }
    }
}

struct LanguagePickerView: View {
    @Binding var showLanguagePicker: Bool
    @EnvironmentObject var languageSettings: LanguageSettings
    @Environment(\.colorScheme) var colorScheme

    var body: some View {
        VStack(spacing: 30) {
            Text("Choose Language")
                .font(.headline)
                .padding()
                .foregroundColor(colorScheme == .dark ? .white : .black)

            HStack(spacing: 50) {
                Button(action: {
                    languageSettings.selectedLanguage = .French
                    showLanguagePicker = false
                }) {
                    VStack {
                        Text(flag(country: "FR"))
                            .font(.system(size: 50))
                        Text("French")
                            .font(.title2)
                            .foregroundColor(colorScheme == .dark ? .white : .black)
                    }
                }

                Button(action: {
                    languageSettings.selectedLanguage = .English
                    showLanguagePicker = false
                }) {
                    VStack {
                        Text(flag(country: "GB"))
                            .font(.system(size: 50))
                        Text("English")
                            .font(.title2)
                            .foregroundColor(colorScheme == .dark ? .white : .black)
                    }
                }
            }

            Button(action: {
                showLanguagePicker = false
            }) {
                Text("Cancel")
                    .font(.title2)
                    .padding()
                    .background(Color.red.opacity(0.7))
                    .foregroundColor(.white)
                    .cornerRadius(10)
            }
            .padding(.top, 20)
        }
        .padding()
    }
}

struct MainMenu_Previews: PreviewProvider {
    static var previews: some View {
        MainMenu(playButtonText: "Play", registeredGamesButtonText: "Registered Games")
            .environmentObject(LanguageSettings(selectedLanguage: .French))
    }
}
